Learn R Programming

subrank (version 0.9.9.3)

desscop: Discrete copula graph, a two-dimensional projection

Description

Draws a discrete joint probability, for 2 variables, using bubbles

Usage

desscop(copest, xname, yname, normalize = FALSE, axes = TRUE)

Arguments

copest

the estimated copula (the whole structure resulting from corc)

xname

the name of the variable we want to put on the horizontal axis

yname

the name of the variable we want to put on the vertical axis

normalize

if TRUE, the smallest probability is rescaled to 0, and the largest to 1

axes

if TRUE, puts the name of the variables on the axes

Author

Jerome Collet

Examples

Run this code
lon <- 31
a <- 2.85
x <- rnorm(lon)
y = a*x^2+rnorm(lon)
tablo = as.data.frame(cbind(x,y))
c=corc(tablo,c("x","y"),8)
desscop(c,"x","y")

tablo = as.data.frame(cbind(x=rep(0,each=lon),y=rep(0,each=lon)))
c=corc(tablo,c("x","y"),8,mixties=TRUE)
desscop(c,"x","y")

Run the code above in your browser using DataLab